==> cmsmadesimple-1.5.3.tgz: cms/modules/TinyMCE/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Editeur TinyMCE WYSIWYG';
$lang['uninstalled'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute;.';
$lang['installed'] = 'La version %s du module a &eacute;t&eacute; install&eacute;e.';
$lang['stripbackgroundtags'] = 'Lors de l&#039;&eacute;dition, affiche avec le CSS, mais sans le fond&nbsp;';
$lang['source_formatting_text'] = 'Appliquer le formatage de la source &agrave; la vue HTML&nbsp;';
$lang['dropdownblockformats_text'] = 'Formatage dans &quot;Bloc de texte&quot;&nbsp;';
$lang['allowtables'] = 'Autoriser des op&eacute;rations sur les tables&nbsp;';
$lang['newlinestyle_text'] = 'Retour &agrave; la ligne (Touche Entr&eacute;e)&nbsp;';
$lang['pstyle'] = 'style p';
$lang['brstyle'] = 'style br/';
$lang['usecompressiontext'] = 'Utilise la compression gz&nbsp;';
$lang['usecompressionhelp'] = 'Cela peut acc&eacute;l&eacute;rer la vitesse de chargement de TinyMCE, mais peut aussi ne pas fonctionner avec votre h&eacute;bergement. Utiliser avec pr&eacute;caution.';
$lang['forcedrootblocktext'] = 'Force &quot;<p> rootblock&quot;&nbsp;';
$lang['forcedrootblockhelp'] = 'Force le contenu retourn&eacute; &agrave; &ecirc;tre au moins inclu dans la balise &amp;lt;p&amp;gt;';
$lang['filepickerstyle'] = 'Style de Filepicker&nbsp;';
$lang['filepickersize'] = 'Taille de Filepicker&nbsp;';
$lang['allowuploadtext'] = 'Autoriser l&#039;upload et la cr&eacute;ation de dossiers avec FilePicker&nbsp;';
$lang['cannotreadconfig'] = 'Impossible de lire le fichier tinyconfig.php, aussi TinyMCE ne fonctionnera probablement pas. Vous devriez v&eacute;rifier les permissions de ce fichier et des dossiers parents, qui doivent avoir les permissions de lecture pour tous et d&#039;&eacute;criture uniquement pour le propri&eacute;taire.';
$lang['filenameonly'] = 'Montrer les noms des fichiers';
$lang['thumbnailsonly'] = 'Montrer les vignettes';
$lang['showthumbnailfilestext'] = 'Afficher les vignettes images dans la liste des fichiers&nbsp;';
$lang['filenameandthumbnails'] = 'Montrer les vignettes et les noms des fichiers';
$lang['skinstext'] = 'Skin&nbsp;';
$lang['skinvariationtext'] = 'Variation de Skin&nbsp;';
$lang['advancedwarning'] = '<strong>ATTENTION !<br/>Le changement de ces param&egrave;tres peut emp&ecirc;cher TinyMCE de fonctionner ou g&eacute;n&eacute;rer du code non conforme. A utiliser seulement si vous savez ce que vous faites ! Consulter le site WEB de TinyMCE avant de modifier.</strong>';
$lang['entityencoding_text'] = 'Encodage des entit&eacute;s&nbsp;';
$lang['rawencoding'] = 'Encodage Raw (plus rapide, convient dans la plupart des cas)';
$lang['namedencoding'] = 'Encodage caract&egrave;res (comme &amp;amp;nbsp;)';
$lang['numericencoding'] = 'Encodage num&eacute;rique (comme &amp;amp;#160;)';
$lang['show_path_text'] = 'Afficher le d&eacute;tail de l&#039;&eacute;l&eacute;ment en bas de l&#039;&eacute;diteur&nbsp;';
$lang['toolbar_tab'] = 'Barres d&#039;outils';
$lang['toolbar_help'] = 'Ces options doivent &ecirc;tre s&eacute;par&eacute;es par une virgule pour ins&eacute;rer un bouton/contr&ocirc;le dans la barre d&#039;outils. le carract&egrave;re | peut &ecirc;tre utiliser en remplacement du mot &#039;separator&#039;';
$lang['toolbar_text'] = 'Barre d&#039;outils';
$lang['toolbarhelptext'] = 'Cliquez ici pour pour voir les instructions de la barre d&#039;outils sur le Wiki de TinyMCE.';
$lang['editor_width_text'] = 'Largeur de l&#039;&eacute;diteur&nbsp;';
$lang['editor_height_text'] = 'Hauteur de l&#039;&eacute;diteur&nbsp;';
$lang['auto'] = 'Auto ';
$lang['or'] = 'ou';
$lang['datetimeformat_text'] = 'Format Date/Heure&nbsp;';
$lang['timetext'] = 'Heure&nbsp;';
$lang['datetext'] = 'Date&nbsp;';
$lang['datetimeformat_help'] = 'Cliquez ici pour l&#039;aide sur le format Date/Heure';
$lang['extraconfigtext'] = 'Extra configuration&nbsp;';
$lang['extraconfighelp'] = 'V&eacute;rifier sur le wiki de TinyMCE pour instructions';
$lang['customdropdowntext'] = 'Dropdown personnalis&eacute;&nbsp;';
$lang['customdropdownhelp'] = 'Insert des snippets personnalis&eacute;s de code/text par s&eacute;lection du Dropdown menu personnalis&eacute;.  Les utilisations des tags sont facilit&eacute;es. Le menu est ins&eacute;r&eacute; dans la barre d&#039;outils en utilisant &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'D&eacute;marrage permis&nbsp;';
$lang['startenabledhelp'] = 'D&eacute;cocher cette case d&eacute;marre Tiny-&eacute;diteurs dans un &eacute;tat d&eacute;sactiv&eacute;. Devrait &ecirc;tre utilis&eacute;e avec la case a cocher &quot;Afficher WYSIWYG Oui/Non&quot;.';
$lang['loadcmslinkertext'] = 'Charger le CMSmslinker&nbsp;';
$lang['loadcmslinkerhelp'] = 'Ceci g&eacute;n&egrave;re le code javascript pour pouvoir ajouter &#039;cmslinker&#039; &agrave; la barre d&#039;outils.';
$lang['cmslinkerstyletext'] = 'Style pour CMS-linker&nbsp;';
$lang['cmsselflinkstyle'] = '{cms_selflink} - style';
$lang['ahrefstyle'] = '&amp;lt;a href&amp;gt; - style';
$lang['relativeurlstext'] = 'G&eacute;n&eacute;rer les urls relatives&nbsp;';
$lang['forcecleanpastetext'] = 'Forcer le nettoyage en collant&nbsp;';
$lang['forcecleanpastehelp'] = 'Cela peut &ecirc;tre utile pour enlever un formatage &eacute;trange lors du collage avec Word etc...';
$lang['bodycss_text'] = 'Tag CSS pour le &quot;Body&quot; de l&#039;&eacute;diteur&nbsp;';
$lang['bodycss_help'] = 'Laisser en blanc ou indiquer &quot;DEFAULT&quot; pour utiliser les CSS. <br/>Note&nbsp;: Pour avoir le fond de page de l&#039;&eacute;diteur en blanc indiquer&nbsp;: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Inclure seulement le CSS pour l&#039;&eacute;cran&nbsp;';
$lang['includeonlyscreencss_help'] = 'La s&eacute;lection permet de joindre des feuilles de style pour &#039;Media type screen&#039; (l&#039;&eacute;cran) qui seront inclus dans la s&eacute;lection &#039;Styles&#039; de l&#039;&eacute;diteur TinyMCE.';
$lang['usestaticconfigtext'] = 'Utilisez le fichier de configuration statique&nbsp;';
$lang['usestaticconfighelp'] = 'Cela peut aider le fonctionnement de Tiny sur des h&eacute;bergement avec par exemple des statistiques... , cassant le code javascript cr&eacute;&eacute; dans le fichier de configuration';
$lang['usestaticconfigwarning'] = 'Attention ! Vous avez coch&eacute; l&#039;option avec un fichier de configuration statique, mais votre dossier / tmp n&#039;a pas les permissions en &eacute;criture. Cela emp&ecirc;chera le module d&#039;enregistrer le fichier de configuration statique et rendra plus que probablement TinyMCE non op&eacute;rationnel.';
$lang['showtogglebutton_text'] = 'Montrer la case &agrave; cocher pour afficher l&#039;&eacute;diteur WYSIWYG Oui/Non&nbsp;';
$lang['togglewysiwyg'] = 'Afficher WYSIWYG Oui/Non';
$lang['styles_tab'] = 'Styles CSS';
$lang['styles_help'] = 'Si vous laissez le premier champ vide, TinyMCE utilisera votre fichier CSS et listera pour l&#039;utilisateur les styles contenus dans ce fichier.
Si vous voulez seulement certains styles pr&eacute;sent&eacute;s &agrave; l&#039;utilisateur, pr&eacute;ciser dans le formulaire ci-dessous :  &quot;mon_style1=style1; mon_style2=style2&quot;, &quot;style1&quot; &eacute;tant une classe appel&eacute;e dans la feuille de style d&eacute;finie pour le gabarit de la page. Cela se traduira par exemple par <span class=&quot;style1&quot;>text</span>.';
$lang['css_styles_text'] = 'G&eacute;n&eacute;ral&nbsp;';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. Veuillez v&eacute;rifier vos permissions.';
$lang['error'] = 'Erreur&nbsp;!';
$lang['submit'] = 'Envoyer';
$lang['update'] = 'Mise &agrave; jour';
$lang['settings'] = 'Ajustements';
$lang['settingssaved'] = 'Ajustements sauvegard&eacute;s';
$lang['advancedsaved'] = 'Ajustements avanc&eacute;s sauvegard&eacute;s';
$lang['toolbarsaved'] = 'Barre d&#039;outils sauvegard&eacute;e';
$lang['stylessaved'] = 'Styles sauvegard&eacute;s';
$lang['testareatext'] = 'Texte de test, aucun contenu ne sera modifi&eacute; avec ceci...';
$lang['reset'] = 'Restaurer par d&eacute;faut';
$lang['resetall'] = 'Restaurer Toute la configuration par d&eacute;faut';
$lang['confirmreset'] = '&Ecirc;tes-vous s&ucirc;r de vouloir restaurer la configuration par d&eacute;faut ?';
$lang['confirmresetall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir restaurer Toute la configuration par d&eacute;faut ?';
$lang['settingsreset'] = 'La configuration par d&eacute;faut est restaur&eacute;e ';
$lang['allsettingsreset'] = 'Toute la configuration par d&eacute;faut est restaur&eacute;e ';
$lang['upgraded'] = 'A &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
$lang['customdropdown'] = 'Dropdown personnalis\351';
$lang['cmsmslinker'] = 'Inserer le lien vers une page cmsms';
$lang['backend_toolbars'] = 'Barre d&#039;outils pour l&#039;administration';
$lang['frontend_toolbars'] = 'Barre d&#039;outils pour le site (Frontend)';
$lang['plugins_tab'] = 'Plugins&nbsp;';
$lang['plugins_help'] = 'Choisir les plugins que vous voulez activer. La documentation est <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">ici</a>';
$lang['plugins_text'] = 'Plugins&nbsp;';
$lang['saveplugins'] = 'Sauvegarde plugins';
$lang['pluginssaved'] = 'Plugins sauvegard&eacute;s';
$lang['youareintext'] = 'Vous &ecirc;tes dans&nbsp;:&nbsp;';
$lang['loadstylesheettext'] = 'Charger la feuille de style pour le contenu (recommand&eacute;)&nbsp;';
$lang['extrastylestext'] = 'Ajouts &agrave; la feuille de style&nbsp;';
$lang['extrastyleshelp'] = 'Le CSS entr&eacute; ici sera ajout&eacute; &agrave; la feuille de style lue par TinyMCE apr&egrave;s la r&eacute;ception des styles de CMSms ';
$lang['uploadnewfile'] = 'Nouveau fichier&nbsp;';
$lang['uploadfile'] = 'Upload&nbsp;';
$lang['createnewdir'] = 'Nouveau dossier&nbsp;';
$lang['createdir'] = 'Cr&eacute;er';
$lang['nodirname'] = 'Aucun nom de dossier';
$lang['direxists'] = 'le dossier existe d&eacute;j&agrave;';
$lang['newdircreated'] = 'Nouveau dossier cr&eacute;&eacute; avec succ&egrave;s';
$lang['newdirfailed'] = 'Une erreur est survenue lors de la cr&eacute;ation du dossier';
$lang['nofile'] = 'Aucun fichier upload&eacute;';
$lang['filetoobig'] = 'Fichier Uploader trop gros';
$lang['uploadfailed'] = 'Erreur lors de l&#039;upload du fichier';
$lang['fileuploaded'] = 'Fichier upload&eacute; avec succ&egrave;s';
$lang['filepickertitle'] = 'Fichiers CMSMadeSimple';
$lang['success'] = 'Succ&egrave;s';
$lang['fileoperations'] = 'Op&eacute;rations sur les fichiers&nbsp;';
$lang['thousanddelimiter'] = '.';
$lang['size'] = 'Taille';
$lang['dimensions'] = 'LargxHaut';
$lang['advanced_tab'] = 'Avanc&eacute;';
$lang['help'] = '	<h3>Que fait ce module&nbsp;?</h3>
	<p>Active TinyMCE pour &ecirc;tre utilis&eacute; en tant que WYSIWYG.</p>
	<h3>Comment l&#039;utiliser?</h3>
	<p>Installez le module, puis allez &agrave; &quot;Mes pr&eacute;f&eacute;rences / Pr&eacute;f&eacute;rences de l&#039;utilisateur&quot; et d&eacute;finissez TinyMCE comme WYSIWYG de votre choix.</p>
<p>Modifier les Permissions des groupes afin d&#039;autoriser les pr&eacute;f&eacute;rences pour TinyMCE.</p>
<h3>D&eacute;pannage</h3>
	Certaines personnes ont des probl&egrave;mes avec Tiny lors de l&#039;installation ou de la mise &agrave; niveau. Voici une liste de 
choses &agrave; essayer avant de me contacter pour obtenir une aide suppl&eacute;mentaire.
	<br/>
	<ul>
	<li>1. S&rsquo;il vous pla&icirc;t, s&rsquo;il vous pla&icirc;t, essayez &agrave; nouveau de renvoyer les fichiers du module TinyMCE vers votre serveur. Cela est une chose qui a aid&eacute; de nombreux utilisateurs.</li>
	<li>2. Essayez de passer avec l&#039;option du fichier de configuration statique. Notez que cela n&eacute;cessite que le dossier /tmp ait des permissions en &eacute;criture.</li>
	<li>3. Si vous faite une mise &agrave; jour, essayer de r&eacute;initialiser tous les param&egrave;tres. Pas &eacute;vident si vous avez personnalis&eacute; plusieurs options, je le sais, mais il y de nombreuses modifications entre les versions 2.3.x &agrave; 2.4.x du module.</li>
	<li>4. Essayez d&#039;activer l&#039;option de configuration statique dans les param&egrave;tres avanc&eacute;s. Cela fonctionne mieux sur certains syst&egrave;mes (CGI-based)</li>
	</ul>
	<br/>';
$lang['utmz'] = '156861353.1234686030.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/topic,18584.msg146491.html|utmcmd=referral';
$lang['utma'] = '156861353.1770932664.1234686030.1234686030.1234715253.2';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> cmsmadesimple-1.6.4.tgz: cms/modules/TinyMCE/lang/ext/fr_FR.php <==
<?php
$lang['friendlyname'] = 'Editeur TinyMCE WYSIWYG';
$lang['uninstalled'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute;.';
$lang['installed'] = 'La version %s du module a &eacute;t&eacute; install&eacute;e.';
$lang['stripbackgroundtags'] = 'Lors de l&#039;&eacute;dition, affiche avec le CSS, mais sans le fond&nbsp;';
$lang['stiptags_help'] = 'Cette option tente de supprimer les param&egrave;tres du type background de la feuille de style.';
$lang['source_formatting_text'] = 'Appliquer le formatage de la source &agrave; la vue HTML&nbsp;';
$lang['dropdownblockformats_text'] = 'Formatage dans &quot;Bloc de texte&quot;&nbsp;';
$lang['allowtables'] = 'Autoriser des op&eacute;rations sur les tables&nbsp;';
$lang['newlinestyle_text'] = 'Retour &agrave; la ligne (Touche Entr&eacute;e)&nbsp;';
$lang['pstyle'] = 'style p';
$lang['brstyle'] = 'style br/';
$lang['usecompressiontext'] = 'Utilise la compression gz&nbsp;';
$lang['usecompressionhelp'] = 'Cela peut acc&eacute;l&eacute;rer la vitesse de chargement de TinyMCE, mais peut aussi ne pas fonctionner avec votre h&eacute;bergement. Utiliser avec pr&eacute;caution.';
$lang['forcedrootblocktext'] = 'Force &quot;< p > rootblock&quot;&nbsp;';
$lang['forcedrootblockhelp'] = 'Force le contenu retourn&eacute; &agrave; &ecirc;tre au moins inclu dans la balise < p >';
$lang['filepickerstyle'] = 'Style de Filepicker&nbsp;';
$lang['filepickersize'] = 'Taille de Filepicker&nbsp;';
$lang['allowuploadtext'] = 'Autoriser l&#039;upload et la cr&eacute;ation de dossiers avec FilePicker&nbsp;';
$lang['allowscalingtext'] = 'Permettre le redimensionnement automatique des images t&eacute;l&eacute;charg&eacute;es&nbsp;';
$lang['scalingdimensionstext'] = 'Dimensions par d&eacute;faut&nbsp;';
$lang['resizeto'] = 'Redimensionner &agrave;&nbsp;:';
$lang['useadvancedprofile'] = 'Utiliser les param&egrave;tres avanc&eacute;s du profil TinyMCE';
$lang['saveprofile'] = 'Sauvegarder le profil';
$lang['profilesaved'] = 'Profil sauvegard&eacute;';
$lang['profiles_tab'] = 'Profils';
$lang['advanced_backend_toolbars'] = 'Profil param&egrave;tres avanc&eacute;s (backend)';
$lang['savestyles'] = 'Sauvegarder les styles';
$lang['allowadvancedprofile'] = 'Autoriser l&#039;utilisation des param&egrave;tres avanc&eacute;s dans le profil de TinyMCE';
$lang['showfilemanagement'] = 'Montrer les options sur les fichiers&nbsp;';
$lang['showfilemanagementhelp'] = 'Afficher les options sur les fichiers comme le t&eacute;l&eacute;chargement, cr&eacute;ation de r&eacute;pertoires et suppression des fichiers avec FilePicker, si l&#039;utilisateur est autoris&eacute; &agrave; effectuer ces op&eacute;rations.';
$lang['deleteconfirmation'] = '&Ecirc;tes-vous s&ucirc;r que ce fichier doit &ecirc;tre supprim&eacute; ?';
$lang['deletefilesuccess'] = 'supprim&eacute; avec succ&egrave;s';
$lang['deletefilefila'] = 'Ne peux pas &ecirc;tre supprim&eacute;';
$lang['cannotreadconfig'] = 'Impossible de lire le fichier tinyconfig.php, aussi TinyMCE ne fonctionnera probablement pas. Vous devriez v&eacute;rifier les permissions de ce fichier et des dossiers parents, qui doivent avoir les permissions de lecture pour tous et d&#039;&eacute;criture uniquement pour le propri&eacute;taire.';
$lang['filenameonly'] = 'Montrer les noms des fichiers';
$lang['thumbnailsonly'] = 'Montrer les vignettes';
$lang['showthumbnailfilestext'] = 'Afficher les vignettes images dans la liste des fichiers&nbsp;';
$lang['filenameandthumbnails'] = 'Montrer les vignettes et les noms des fichiers';
$lang['skinstext'] = 'Skin&nbsp;';
$lang['skinvariationtext'] = 'Variation de Skin&nbsp;';
$lang['advancedwarning'] = '<strong>ATTENTION !<br/>Le changement de ces param&egrave;tres peut emp&ecirc;cher TinyMCE de fonctionner ou g&eacute;n&eacute;rer du code non conforme. A utiliser seulement si vous savez ce que vous faites ! Consulter le site WEB de TinyMCE avant de modifier.</strong>';
$lang['entityencoding_text'] = 'Encodage des entit&eacute;s&nbsp;';
$lang['rawencoding'] = 'Encodage Raw (plus rapide, convient dans la plupart des cas)';
$lang['namedencoding'] = 'Encodage caract&egrave;res (comme &amp;amp;nbsp;)';
$lang['numericencoding'] = 'Encodage num&eacute;rique (comme &amp;amp;#160;)';
$lang['show_path_text'] = 'Afficher le d&eacute;tail de l&#039;&eacute;l&eacute;ment en bas de l&#039;&eacute;diteur&nbsp;';
$lang['toolbar_tab'] = 'Barres d&#039;outils';
$lang['toolbar_help'] = 'Ces options doivent &ecirc;tre s&eacute;par&eacute;es par une virgule pour ins&eacute;rer un bouton/contr&ocirc;le dans la barre d&#039;outils. le carract&egrave;re | peut &ecirc;tre utiliser en remplacement du mot &#039;separator&#039;';
$lang['toolbar_text'] = 'Barre d&#039;outils';
$lang['toolbarhelptext'] = 'Cliquez ici pour pour voir les instructions de la barre d&#039;outils sur le Wiki de TinyMCE.';
$lang['editor_width_text'] = 'Largeur de l&#039;&eacute;diteur&nbsp;';
$lang['editor_height_text'] = 'Hauteur de l&#039;&eacute;diteur&nbsp;';
$lang['auto'] = 'Auto ';
$lang['or'] = 'ou';
$lang['datetimeformat_text'] = 'Format Date/Heure&nbsp;';
$lang['timetext'] = 'Heure&nbsp;';
$lang['datetext'] = 'Date&nbsp;';
$lang['datetimeformat_help'] = 'Cliquez ici pour l&#039;aide sur le format Date/Heure';
$lang['extraconfigtext'] = 'Extra configuration&nbsp;';
$lang['extraconfighelp'] = 'Une d&eacute;claration par ligne, sans virgule, merci de v&eacute;rifier sur le wiki de TinyMCE pour instructions';
$lang['customdropdowntext'] = 'Dropdown personnalis&eacute;&nbsp;';
$lang['customdropdownhelp'] = 'Insert des snippets personnalis&eacute;s de code/text par s&eacute;lection du Dropdown menu personnalis&eacute;.  Les utilisations des tags sont facilit&eacute;es. Le menu est ins&eacute;r&eacute; dans la barre d&#039;outils en utilisant &#039;customdropdown&#039;.';
$lang['startenabledtext'] = 'D&eacute;marrage permis&nbsp;';
$lang['startenabledhelp'] = 'D&eacute;cocher cette case d&eacute;marre Tiny-&eacute;diteurs dans un &eacute;tat d&eacute;sactiv&eacute;. Devrait &ecirc;tre utilis&eacute;e avec la case a cocher &quot;Afficher WYSIWYG Oui/Non&quot;.';
$lang['loadcmslinkertext'] = 'Charger le CMSmslinker&nbsp;';
$lang['loadcmslinkerhelp'] = 'Ceci g&eacute;n&egrave;re le code javascript pour pouvoir ajouter &#039;cmslinker&#039; &agrave; la barre d&#039;outils.';
$lang['cmslinkerstyletext'] = 'Style pour CMS-linker&nbsp;';
$lang['cmsselflinkstyle'] = '{cms_selflink} - style';
$lang['ahrefstyle'] = '< a href > - style';
$lang['relativeurlstext'] = 'G&eacute;n&eacute;rer les urls relatives&nbsp;';
$lang['forcecleanpastetext'] = 'Forcer le nettoyage en collant&nbsp;';
$lang['forcecleanpastehelp'] = 'Cela peut &ecirc;tre utile pour enlever un formatage &eacute;trange lors du collage avec Word etc...';
$lang['bodycss_text'] = 'Tag CSS pour le &quot;Body&quot; de l&#039;&eacute;diteur&nbsp;';
$lang['bodycss_help'] = 'Laisser en blanc ou indiquer &quot;DEFAULT&quot; pour utiliser les CSS. <br/>Note&nbsp;: Pour avoir le fond de page de l&#039;&eacute;diteur en blanc indiquer&nbsp;: background-color:white;';
$lang['includeonlyscreencss_text'] = 'Inclure seulement le CSS pour l&#039;&eacute;cran&nbsp;';
$lang['includeonlyscreencss_help'] = 'La s&eacute;lection permet de joindre des feuilles de style pour &#039;Media type screen&#039; (l&#039;&eacute;cran) qui seront inclus dans la s&eacute;lection &#039;Styles&#039; de l&#039;&eacute;diteur TinyMCE.';
$lang['usestaticconfigtext'] = 'Utilisez le fichier de configuration statique&nbsp;';
$lang['usestaticconfighelp'] = 'Cela peut aider le fonctionnement de Tiny sur des h&eacute;bergement avec par exemple des statistiques... , cassant le code javascript cr&eacute;&eacute; dans le fichier de configuration';
$lang['usestaticconfigwarning'] = 'Attention ! Vous avez coch&eacute; l&#039;option avec un fichier de configuration statique, mais votre dossier / tmp n&#039;a pas les permissions en &eacute;criture. Cela emp&ecirc;chera le module d&#039;enregistrer le fichier de configuration statique et rendra plus que probablement TinyMCE non op&eacute;rationnel.';
$lang['showtogglebutton_text'] = 'Montrer la case &agrave; cocher pour afficher l&#039;&eacute;diteur WYSIWYG Oui/Non&nbsp;';
$lang['togglewysiwyg'] = 'Afficher WYSIWYG Oui/Non';
$lang['styles_tab'] = 'Styles CSS';
$lang['styles_help'] = 'Si vous laissez le premier champ vide, TinyMCE utilisera votre fichier CSS et listera pour l&#039;utilisateur les styles contenus dans ce fichier.
Si vous voulez seulement certains styles pr&eacute;sent&eacute;s &agrave; l&#039;utilisateur, pr&eacute;ciser dans le formulaire ci-dessous :  &quot;mon_style1=style1; mon_style2=style2&quot;, &quot;style1&quot; &eacute;tant une classe appel&eacute;e dans la feuille de style d&eacute;finie pour le gabarit de la page. Cela se traduira par exemple par < span class=&quot;style1&quot; >text< /span >.';
$lang['css_styles_text'] = 'G&eacute;n&eacute;ral&nbsp;';
$lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. Veuillez v&eacute;rifier vos permissions.';
$lang['error'] = 'Erreur&nbsp;!';
$lang['submit'] = 'Envoyer';
$lang['update'] = 'Mise &agrave; jour';
$lang['savesettings'] = 'Sauvegarder les ajustements';
$lang['settings'] = 'Ajustements';
$lang['settingssaved'] = 'Ajustements sauvegard&eacute;s';
$lang['saveadvanced'] = 'Sauvegarder les ajustements avanc&eacute;s';
$lang['advancedsaved'] = 'Ajustements avanc&eacute;s sauvegard&eacute;s';
$lang['toolbarsaved'] = 'Barre d&#039;outils sauvegard&eacute;e';
$lang['stylessaved'] = 'Styles sauvegard&eacute;s';
$lang['testareatext'] = '<p>Texte de test, aucun contenu ne sera modifi&eacute; avec ceci...</p>';
$lang['reset'] = 'Restaurer par d&eacute;faut';
$lang['resetall'] = 'Restaurer Toute la configuration par d&eacute;faut';
$lang['confirmreset'] = '&Ecirc;tes-vous s&ucirc;r de vouloir restaurer la configuration par d&eacute;faut ?';
$lang['confirmresetall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir restaurer Toute la configuration par d&eacute;faut ?';
$lang['settingsreset'] = 'La configuration par d&eacute;faut est restaur&eacute;e ';
$lang['allsettingsreset'] = 'Toute la configuration par d&eacute;faut est restaur&eacute;e ';
$lang['upgraded'] = 'A &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
$lang['customdropdown'] = 'Dropdown personnalis\351';
$lang['cmsmslinker'] = 'Inserer le lien vers une page cmsms';
$lang['backend_toolbars'] = 'Profil de barre d&#039;outils pour l&#039;administration';
$lang['frontend_toolbars'] = 'Profil de barre d&#039;outils pour le site (Frontend)';
$lang['plugins_tab'] = 'Plugins&nbsp;';
$lang['plugins_help'] = 'Choisir les plugins que vous voulez activer. La documentation est <a href="http://wiki.moxiecode.com/index.php/TinyMCE:Plugins" target="_blank">ici</a>';
$lang['plugins_text'] = 'Plugins&nbsp;';
$lang['saveplugins'] = 'Sauvegarder les plugins';
$lang['pluginssaved'] = 'Plugins sauvegard&eacute;s';
$lang['youareintext'] = 'Vous &ecirc;tes dans&nbsp;:&nbsp;';
$lang['loadstylesheettext'] = 'Charger la feuille de style pour le contenu (recommand&eacute;)&nbsp;';
$lang['extrastylestext'] = 'Ajouts &agrave; la feuille de style&nbsp;';
$lang['extrastyleshelp'] = 'Le CSS entr&eacute; ici sera ajout&eacute; &agrave; la feuille de style lue par TinyMCE apr&egrave;s la r&eacute;ception des styles de CMSms ';
$lang['uploadnewfile'] = 'Nouveau fichier&nbsp;';
$lang['uploadfile'] = 'Uploader';
$lang['createnewdir'] = 'Nouveau dossier&nbsp;';
$lang['createdir'] = 'Cr&eacute;er';
$lang['nodirname'] = 'Aucun nom de dossier';
$lang['direxists'] = 'le dossier existe d&eacute;j&agrave;';
$lang['newdircreated'] = 'Nouveau dossier cr&eacute;&eacute; avec succ&egrave;s';
$lang['newdirfailed'] = 'Une erreur est survenue lors de la cr&eacute;ation du dossier';
$lang['nofile'] = 'Aucun fichier upload&eacute;';
$lang['filetoobig'] = 'Fichier Uploader trop gros';
$lang['uploadfailed'] = 'Erreur lors de l&#039;upload du fichier';
$lang['fileuploaded'] = 'Fichier upload&eacute; avec succ&egrave;s';
$lang['filepickertitle'] = 'Fichiers CMSMadeSimple';
$lang['success'] = 'Succ&egrave;s';
$lang['fileoperations'] = 'Op&eacute;rations sur les fichiers&nbsp;';
$lang['thousanddelimiter'] = '.';
$lang['size'] = 'Taille';
$lang['dimensions'] = 'LargxHaut';
$lang['advanced_tab'] = 'Avanc&eacute;';
$lang['help'] = '	<h3>Que fait ce module&nbsp;?</h3>
	<p>Active TinyMCE pour &ecirc;tre utilis&eacute; en tant que WYSIWYG.</p>
	<h3>Comment l&#039;utiliser?</h3>
	<p>Installez le module, puis allez &agrave; &quot;Mes pr&eacute;f&eacute;rences / Pr&eacute;f&eacute;rences de l&#039;utilisateur&quot; et d&eacute;finissez TinyMCE comme WYSIWYG de votre choix.</p>
<p>Modifier les Permissions des groupes afin d&#039;autoriser les pr&eacute;f&eacute;rences pour TinyMCE.</p>
<h3>D&eacute;pannage</h3>
	Certaines personnes ont des probl&egrave;mes avec Tiny lors de l&#039;installation ou de la mise &agrave; niveau. Voici une liste de 
choses &agrave; essayer avant de me contacter pour obtenir une aide suppl&eacute;mentaire.
	<br/>
	<ul>
	<li>1. S&rsquo;il vous pla&icirc;t, s&rsquo;il vous pla&icirc;t, essayez &agrave; nouveau de renvoyer les fichiers du module TinyMCE vers votre serveur. Cela est une chose qui a aid&eacute; de nombreux utilisateurs.</li>
	<li>2. Essayez de passer avec l&#039;option du fichier de configuration statique. Notez que cela n&eacute;cessite que le dossier /tmp ait des permissions en &eacute;criture.</li>
	<li>3. Si vous faite une mise &agrave; jour, essayer de r&eacute;initialiser tous les param&egrave;tres. Pas &eacute;vident si vous avez personnalis&eacute; plusieurs options, je le sais, mais il y de nombreuses modifications entre les versions 2.3.x &agrave; 2.4.x du module.</li>
	<li>4. Essayez d&#039;activer l&#039;option de configuration statique dans les param&egrave;tres avanc&eacute;s. Cela fonctionne mieux sur certains syst&egrave;mes (CGI-based)</li>
	</ul>
	<br/>';
$lang['utma'] = '156861353.1396160384.1247815107.1247815107.1247815107.1';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1247815107.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
?>
